Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8057)

Unified Diff: chrome/browser/ui/views/frame/browser_view_layout.h

Issue 6913026: Compact Navigation prototype (Closed) Base URL: http://git.chromium.org/git/chromium.git@trunk
Patch Set: Clang build fix. After commit/revert. Created 9 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/views/frame/browser_view.cc ('k') | chrome/browser/ui/views/frame/browser_view_layout.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/views/frame/browser_view_layout.h
===================================================================
--- chrome/browser/ui/views/frame/browser_view_layout.h (revision 84869)
+++ chrome/browser/ui/views/frame/browser_view_layout.h (working copy)
@@ -62,9 +62,11 @@
Browser* browser();
const Browser* browser() const;
- // Layout the TabStrip, returns the coordinate of the bottom of the TabStrip,
- // for laying out subsequent controls.
- virtual int LayoutTabStrip();
+ // Layout the tab strip region, returns the coordinate of the bottom of the
+ // TabStrip, for laying out subsequent controls. This also lays out the
+ // compact navigation and options bars if the browser is in compact navigation
+ // mode.
+ virtual int LayoutTabStripRegion();
// Layout the following controls, starting at |top|, returns the coordinate
// of the bottom of the control, for laying out the next control.
@@ -112,6 +114,9 @@
views::SingleSplitView* contents_split_;
ContentsContainer* contents_container_;
views::View* infobar_container_;
+ views::View* compact_navigation_bar_;
+ views::View* compact_options_bar_;
+ views::View* compact_spacer_;
DownloadShelfView* download_shelf_;
BookmarkBarView* active_bookmark_bar_;
« no previous file with comments | « chrome/browser/ui/views/frame/browser_view.cc ('k') | chrome/browser/ui/views/frame/browser_view_layout.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698